@@ -42,13 +42,8 @@ plotwin <- function(dataset, cw = 0.95){
       geom_text(data = p_meds, aes(x = variable, y = value, label = value),
                 size = 5, vjust = -1.9) +
       coord_flip()+
-      theme_classic()+
-      theme(panel.grid.major = element_blank(),
-            panel.grid.minor = element_blank(),
-            axis.line = element_line(size = 0.25, colour = "black"),
-            axis.text.y = element_text(angle = 90, hjust = 0.5,size = 10),
-            plot.title = element_text(size = 16, hjust = 0.5),
-            panel.border = element_rect(colour = "black", fill = NA))+
+      theme_climwin()+
+      theme(axis.text.y = element_text(angle = 90, hjust = 0.5,size = 10))+
       ggtitle(paste("Climate window range for \n", (cw*100), "% confidence set"))+
       xlab("")+
       ylab("Climate window")
